==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/getbwertvbextfilter.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS getbwertvbextfilter//
create function getbwertvbextfilter(wid integer, von datetime, bis datetime,
  mode varchar(12), zvon time, zbis time, wtf varchar(20),
  vg1 varchar(3), wf1 varchar(250),
  m2 varchar(3), vg2 varchar(3), wf2 varchar(250),
  m3 varchar(3), vg3 varchar(3), wf3 varchar(250),
  m4 varchar(3), vg4 varchar(3), wf4 varchar(250))
                  returns varchar(30)
deterministic
sql security invoker
begin
  declare r, l varchar(20);
  declare ld datetime;
  declare va, ba, vo, bo time;
  declare f integer;
  if TIME(zvon) < TIME(zbis)
   then
    set va = TIME(zvon);
    set ba = TIME(zbis);
    set vo = '24:00:00';
    set bo = '-00:00:01';
  else
    set va = '24:00:00';
    set ba = '-00:00:01';
    set vo = TIME(zvon);
    set bo = TIME(zbis);
  end if;
  case mode
    when 'differ' then
      return (select datenID from bwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(dateiname, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum desc limit 1)
          != (select datenID from bwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(dateiname, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum limit 1);
    when 'count' then
      select count(*) from bwerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(dateiname, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
      into r;
    else
      return '';
  end case;
  return r;
end//

GRANT EXECUTE on FUNCTION getbwertvbextfilter to logginglesen@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/getbwertvbextfilter.sql <==
-- getbwertvbextfilter.sql
--
-- function getbwertvbextfilter(wid, von, bis, mode, zvon, zbis, wtf, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4) returns varchar
-- wid: werteindizesID
-- von: datetime from
-- bis: datetime to
-- mode: aggregation function
-- zvon: time from
-- zbis: time to
-- wtf: set of weekdays
-- vg1: comparevalue 1
-- wf1: comparefunction 1
-- m2: OR|AND
-- vg2: comparevalue 2
-- wf2: comparefunction 2
-- m3: OR|AND
-- vg3: comparevalue 3
-- wf3: comparefunction 3
-- m4: OR|AND
-- vg4: comparevalue 4
-- wf4: comparefunction 4
-- return: aggragated value with extended filter for binary data (table bwerte)

set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS getbwertvbextfilter//
create function getbwertvbextfilter(wid integer, von datetime, bis datetime,
  mode varchar(12), zvon time, zbis time, wtf varchar(20),
  vg1 varchar(3), wf1 varchar(250),
  m2 varchar(3), vg2 varchar(3), wf2 varchar(250),
  m3 varchar(3), vg3 varchar(3), wf3 varchar(250),
  m4 varchar(3), vg4 varchar(3), wf4 varchar(250))
                  returns varchar(30)
deterministic
sql security invoker
begin
  declare r, l varchar(20);
  declare ld datetime;
  declare va, ba, vo, bo time;
  declare f integer;
  if TIME(zvon) < TIME(zbis)
   then
    set va = TIME(zvon);
    set ba = TIME(zbis);
    set vo = '24:00:00';
    set bo = '-00:00:01';
  else
    set va = '24:00:00';
    set ba = '-00:00:01';
    set vo = TIME(zvon);
    set bo = TIME(zbis);
  end if;
  case mode
    when 'differ' then
      return (select datenID from bwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(dateiname, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum desc limit 1)
          != (select datenID from bwerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(dateiname, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4)
              order by datum limit 1);
    when 'count' then
      select count(*) into r from bwerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(dateiname, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    else
      return '';
  end case;
  return r;
end//

GRANT EXECUTE on FUNCTION getbwertvbextfilter to logginglesen@'localhost'//
